Method: SQLite::API.aggregate_count
- Defined in:
- ext/sqlite-api.c
.aggregate_count(func) ⇒ Fixnum
Returns the number of rows that have been processed so far by the current aggregate function. This always includes the current row, so that number that is returned will always be at least 1.
The func parameter must be an opaque function handle as given to the callbacks for #create_aggregate.
870 871 872 873 874 875 876 877 |
# File 'ext/sqlite-api.c', line 870
static VALUE
static_api_aggregate_count( VALUE module, VALUE func )
{
sqlite_func *func_ptr;
GetFunc( func_ptr, func );
return INT2FIX( sqlite_aggregate_count( func_ptr ) );
}
|