Method: SQLite::Database::FunctionProxy#initialize
- Defined in:
- lib/sqlite/database.rb
#initialize(func, context = nil) ⇒ FunctionProxy
Create a new FunctionProxy that encapsulates the given func object. If context is non-nil, the functions context will be set to that. If it is non-nil, it must quack like a Hash. If it is nil, then none of the context functions will be available.
628 629 630 631 |
# File 'lib/sqlite/database.rb', line 628 def initialize( func, context=nil ) @func = func @context = context end |